@@ -27,8 +27,11 @@
 #define BI_PNG       5   /* BMP version 5 (not yet supported) */
 
 #define WIN_OS2_OLD 12
-#define WIN_NEW     40
 #define OS2_NEW     64
+#define WIN_3X      40
+#define WIN_95_NT4  108
+#define WIN_98_2K   124
+#define WIN_NT_2K   128
 
 #if (defined(UINT_MAX) && UINT_MAX != 0xffffffffU)
 #  error XV's BMP code requires 32-bit unsigned integer type, but u_int isn't
@@ -36,12 +39,12 @@
 
 static long filesize;
 
-static int   loadBMP1   PARM((FILE *, byte *, u_int, u_int));
-static int   loadBMP4   PARM((FILE *, byte *, u_int, u_int, u_int));
-static int   loadBMP8   PARM((FILE *, byte *, u_int, u_int, u_int));
-static int   loadBMP16  PARM((FILE *, byte *, u_int, u_int, u_int *));
-static int   loadBMP24  PARM((FILE *, byte *, u_int, u_int, u_int));
-static int   loadBMP32  PARM((FILE *, byte *, u_int, u_int, u_int *));
+static int   loadBMP1   PARM((FILE *, byte *, u_int, u_int, int));
+static int   loadBMP4   PARM((FILE *, byte *, u_int, u_int, u_int, int));
+static int   loadBMP8   PARM((FILE *, byte *, u_int, u_int, u_int, int));
+static int   loadBMP16  PARM((FILE *, byte *, u_int, u_int, u_int *, int));
+static int   loadBMP24  PARM((FILE *, byte *, u_int, u_int, u_int, int));
+static int   loadBMP32  PARM((FILE *, byte *, u_int, u_int, u_int *, int));
 static u_int getshort   PARM((FILE *));
 static u_int getint     PARM((FILE *));
 static void  putshort   PARM((FILE *, int));
@@ -56,17 +59,17 @@ static int   bmpError   PARM((const char *, const char *));
 #define FERROR(fp) (ferror(fp) || feof(fp))
 
 /*******************************************/
-int LoadBMP(fname, pinfo)
-     char    *fname;
-     PICINFO *pinfo;
+int LoadBMP(char *fname, PICINFO *pinfo)
 /*******************************************/
 {
   FILE       *fp;
-  int        i, c, c1, rv, bPad;
-  u_int      bfSize, bfOffBits, biSize, biWidth, biHeight, biPlanes;
+  int        i, c, c1, rv, bPad, rightsideup = 0;
+  u_int      bfSize, bfOffBits, biSize, biWidth, biPlanes;
   u_int      biBitCount, biCompression, biSizeImage, biXPelsPerMeter;
   u_int      biYPelsPerMeter, biClrUsed, biClrImportant;
+  u_int      npixels;
   u_int      colormask[3];
+  int        biHeight;
   char       buf[512], rgb_bits[16];
   const char *cmpstr, *bname;
   byte       *pic24, *pic8;
@@ -95,7 +98,8 @@ int LoadBMP(fname, pinfo)
 
   biSize          = getint(fp);
 
-  if (biSize == WIN_NEW || biSize == OS2_NEW) {
+  if (biSize == WIN_3X || biSize == OS2_NEW ||
+	biSize == WIN_95_NT4 || biSize == WIN_98_2K || biSize == WIN_NT_2K) {
     biWidth         = getint(fp);
     biHeight        = getint(fp);
     biPlanes        = getshort(fp);
@@ -121,6 +125,22 @@ int LoadBMP(fname, pinfo)
     biClrUsed       = biClrImportant  = 0;
   }
 
+  /* Height could be negative for uncompressed BMP files if data is
+     stored right-side-up */
+  npixels = biWidth * biHeight;
+  if (biWidth != 0 && npixels/biWidth != biHeight && biCompression == BI_RGB) {
+    u_int negHeight, npixels2;
+
+    negHeight = biHeight * -1;
+    npixels2 = biWidth * negHeight;
+
+    if (npixels2/biWidth == negHeight) {
+      biHeight = negHeight;
+      npixels = npixels2;
+      rightsideup = 1;
+    }
+  }
+
   if (DEBUG>1) {
     fprintf(stderr,"\nLoadBMP:\tbfSize=%d, bfOffBits=%d\n",bfSize,bfOffBits);
     fprintf(stderr,"\t\tbiSize=%d, biWidth=%d, biHeight=%d, biPlanes=%d\n",
@@ -191,6 +211,9 @@ int LoadBMP(fname, pinfo)
     bPad -= 12;
   }
 
+  if (biClrUsed > (1 << biBitCount))
+    biClrUsed = (1 << biBitCount);
+
   /* load up colormap, if any */
   if (biBitCount == 1 || biBitCount == 4 || biBitCount == 8) {
     int i, cmaplen;
@@ -231,21 +254,18 @@ int LoadBMP(fname, pinfo)
   /* create pic8 or pic24 */
 
   if (biBitCount==16 || biBitCount==24 || biBitCount==32) {
-    u_int npixels = biWidth * biHeight;
     u_int count = 3 * npixels;
 
     if (biWidth == 0 || biHeight == 0 || npixels/biWidth != biHeight ||
         count/3 != npixels)
       return (bmpError(bname, "image dimensions too large"));
-    pic24 = (byte *) calloc((size_t) count, (size_t) 1);
+    pic24 = (byte *) calloc((size_t) (count + 1), (size_t) 1);
     if (!pic24) return (bmpError(bname, "couldn't malloc 'pic24'"));
   }
   else {
-    u_int npixels = biWidth * biHeight;
-
     if (biWidth == 0 || biHeight == 0 || npixels/biWidth != biHeight)
       return (bmpError(bname, "image dimensions too large"));
-    pic8 = (byte *) calloc((size_t) npixels, (size_t) 1);
+    pic8 = (byte *) calloc((size_t) (npixels + 1), (size_t) 1);
     if (!pic8) return(bmpError(bname, "couldn't malloc 'pic8'"));
   }
 
@@ -254,23 +274,24 @@ int LoadBMP(fname, pinfo)
   /* load up the image */
   switch (biBitCount) {
   case 1:
-    rv = loadBMP1(fp, pic8, biWidth, biHeight);
+    rv = loadBMP1(fp, pic8, biWidth, biHeight, rightsideup);
     break;
   case 4:
-    rv = loadBMP4(fp, pic8, biWidth, biHeight, biCompression);
+    rv = loadBMP4(fp, pic8, biWidth, biHeight, biCompression, rightsideup);
     break;
   case 8:
-    rv = loadBMP8(fp, pic8, biWidth, biHeight, biCompression);
+    rv = loadBMP8(fp, pic8, biWidth, biHeight, biCompression, rightsideup);
     break;
   case 16:
     rv = loadBMP16(fp, pic24, biWidth, biHeight,           /*  v-- BI_RGB */
-                   biCompression == BI_BITFIELDS? colormask : NULL);
+                   biCompression == BI_BITFIELDS? colormask : NULL,
+                   rightsideup);
     break;
   default:
     if (biBitCount == 32 && biCompression == BI_BITFIELDS)
-      rv = loadBMP32(fp, pic24, biWidth, biHeight, colormask);
+      rv = loadBMP32(fp, pic24, biWidth, biHeight, colormask, rightsideup);
     else /* 24 or (32 and BI_RGB) */
-      rv = loadBMP24(fp, pic24, biWidth, biHeight, biBitCount);
+      rv = loadBMP24(fp, pic24, biWidth, biHeight, biBitCount, rightsideup);
     break;
   }
 
@@ -315,8 +336,12 @@ int LoadBMP(fname, pinfo)
   pinfo->colType = F_FULLCOLOR;
 
   sprintf(pinfo->fullInfo, "%sBMP, %d bit%s per pixel%s.  (%ld bytes)",
-	  ((biSize==WIN_OS2_OLD) ? "Old OS/2 " :
-	   (biSize==WIN_NEW)     ? "Windows "  : ""),
+	  ((biSize==WIN_OS2_OLD) ? "OS/2 1.x " :
+	   (biSize==OS2_NEW)     ? "OS/2 2.x " :
+	   (biSize==WIN_3X)      ? "Windows 3.x "  :
+	   (biSize==WIN_95_NT4)  ? "Windows 95/NT4 " :
+	   (biSize==WIN_98_2K)   ? "Windows 98/2000" :
+	   (biSize==WIN_NT_2K)   ? "Windows NT/2000 " : ""),
 	  biBitCount,  (biBitCount == 1) ? "" : "s",
 	  cmpstr, filesize);
 
@@ -333,19 +358,27 @@ int LoadBMP(fname, pinfo)
 
 
 /*******************************************/
-static int loadBMP1(fp, pic8, w, h)
-     FILE *fp;
-     byte *pic8;
-     u_int  w,h;
+static int loadBMP1(FILE *fp, byte *pic8, u_int w, u_int h, int rightsideup)
 {
-  int   i,j,c,bitnum,padw;
+  int   i,j,c,bitnum,padw,ibegin,iend,iinc;
   byte *pp = pic8 + ((h - 1) * w);
   size_t l = w*h;
 
   c = 0;
   padw = ((w + 31)/32) * 32;  /* 'w', padded to be a multiple of 32 */
 
-  for (i=h-1; i>=0 && (pp - pic8 <= l); i--) {
+  if (rightsideup) {
+    ibegin = 0;
+    iend = h;
+    iinc = 1;
+  }
+  else {
+    ibegin = h-1;
+    iend = -1;
+    iinc = -1;
+  }
+
+  for (i = ibegin; i != iend && (pp - pic8 <= l); i += iinc) {
     pp = pic8 + (i * w);
     if ((i&0x3f)==0) WaitCursor();
     for (j=bitnum=0; j<padw; j++,bitnum++) {
@@ -368,12 +401,10 @@ static int loadBMP1(fp, pic8, w, h)
 
 
 /*******************************************/
-static int loadBMP4(fp, pic8, w, h, comp)
-     FILE *fp;
-     byte *pic8;
-     u_int  w,h,comp;
+static int loadBMP4(FILE *fp, byte *pic8, u_int w, u_int h, u_int comp, int rightsideup)
 {
   int   i,j,c,c1,x,y,nybnum,padw,rv;
+  int   begin, end, inc;
   byte *pp = pic8 + ((h - 1) * w);
   size_t l = w*h;
 
@@ -381,9 +412,20 @@ static int loadBMP4(fp, pic8, w, h, comp)
   c = c1 = 0;
 
   if (comp == BI_RGB) {   /* read uncompressed data */
+    if (rightsideup) {
+      begin = 0;
+      end = h;
+      inc = 1;
+    }
+    else {
+      begin = h-1;
+      end = -1;
+      inc = -1;
+    }
+
     padw = ((w + 7)/8) * 8; /* 'w' padded to a multiple of 8pix (32 bits) */
 
-    for (i=h-1; i>=0 && (pp - pic8 <= l); i--) {
+    for (i = begin; i != end && (pp - pic8 <= l); i += inc) {
       pp = pic8 + (i * w);
       if ((i&0x3f)==0) WaitCursor();
 
@@ -454,24 +496,33 @@ static int loadBMP4(fp, pic8, w, h, comp)
 
 
 /*******************************************/
-static int loadBMP8(fp, pic8, w, h, comp)
-     FILE *fp;
-     byte *pic8;
-     u_int  w,h,comp;
+static int loadBMP8(FILE *fp, byte *pic8, u_int w, u_int h, u_int comp, int rightsideup)
 {
   int   i,j,c,c1,padw,x,y,rv;
+  int   begin, end, inc;
   byte *pp = pic8 + ((h - 1) * w);
   size_t l = w*h;
   byte *pend;
 
   rv = 0;
 
-  pend = pic8 + w * h;
+  pend = pic8 + l;
 
   if (comp == BI_RGB) {   /* read uncompressed data */
+    if (rightsideup) {
+      begin = 0;
+      end = h;
+      inc = 1;
+    }
+    else {
+      begin = h-1;
+      end = -1;
+      inc = -1;
+    }
+
     padw = ((w + 3)/4) * 4; /* 'w' padded to a multiple of 4pix (32 bits) */
 
-    for (i=h-1; i>=0 && (pp - pic8 <= l); i--) {
+    for (i = begin; i != end && (pp - pic8 <= l); i += inc) {
       pp = pic8 + (i * w);
       if ((i&0x3f)==0) WaitCursor();
 
@@ -534,12 +585,9 @@ static int loadBMP8(fp, pic8, w, h, comp)
 
 
 /*******************************************/
-static int loadBMP16(fp, pic24, w, h, mask)
-     FILE  *fp;
-     byte  *pic24;
-     u_int w, h, *mask;
+static int loadBMP16(FILE *fp, byte *pic24, u_int w, u_int h, u_int *mask, int rightsideup)
 {
-  int	 x, y;
+  int	 x, y, ybegin, yend, yinc;
   byte	*pp = pic24 + ((h - 1) * w * 3);
   size_t l = w*h*3;
   u_int	 buf, colormask[6];
@@ -611,7 +659,18 @@ static int loadBMP16(fp, pic24, w, h, mask)
 	    colorbits[2], colormask[2], bitshift[2], bitshift2[2],
 	    colormask[5], bitshift[5], bitshift2[5]);
 
-  for (y = h-1; y >= 0 && (pp - pic24 <= l); y--) {
+  if (rightsideup) {
+    ybegin = 0;
+    yend = h;
+    yinc = 1;
+  }
+  else {
+    ybegin = h-1;
+    yend = -1;
+    yinc = -1;
+  }
+
+  for (y = ybegin; y != yend && (pp - pic24 <= l); y += yinc) {
     pp = pic24 + (3 * w * y);
     if ((y&0x3f)==0) WaitCursor();
 
@@ -638,12 +697,9 @@ static int loadBMP16(fp, pic24, w, h, mask)
 
 
 /*******************************************/
-static int loadBMP24(fp, pic24, w, h, bits)   /* also handles 32-bit BI_RGB */
-     FILE *fp;
-     byte *pic24;
-     u_int  w,h, bits;
+static int loadBMP24(FILE *fp, byte *pic24, u_int w, u_int h, u_int bits, int rightsideup)   /* also handles 32-bit BI_RGB */
 {
-  int   i,j,padb,rv;
+  int   i,j,padb,rv,ibegin,iend,iinc;
   byte *pp = pic24 + ((h - 1) * w * 3);
   size_t l = w*h*3;
 
@@ -652,7 +708,18 @@ static int loadBMP24(fp, pic24, w, h, bits)   /* also handles 32-bit BI_RGB */
   padb = (4 - ((w*3) % 4)) & 0x03;  /* # of pad bytes to read at EOscanline */
   if (bits==32) padb = 0;
 
-  for (i=h-1; i>=0; i--) {
+  if (rightsideup) {
+    ibegin = 0;
+    iend = h;
+    iinc = 1;
+  }
+  else {
+    ibegin = h-1;
+    iend = -1;
+    iinc = -1;
+  }
+
+  for (i=ibegin; i != iend; i+=iinc) {
     pp = pic24 + (i * w * 3);
     if ((i&0x3f)==0) WaitCursor();
 
@@ -676,12 +743,9 @@ static int loadBMP24(fp, pic24, w, h, bits)   /* also handles 32-bit BI_RGB */
 
 
 /*******************************************/
-static int loadBMP32(fp, pic24, w, h, colormask) /* 32-bit BI_BITFIELDS only */
-     FILE  *fp;
-     byte  *pic24;
-     u_int w, h, *colormask;
+static int loadBMP32(FILE *fp, byte *pic24, u_int w, u_int h, u_int *colormask, int rightsideup) /* 32-bit BI_BITFIELDS only */
 {
-  int	 x, y;
+  int	 x, y, ybegin, yend, yinc;
   byte	*pp;
   u_int	 buf;
   int	 i, bit, bitshift[3], colorbits[3], bitshift2[3];
@@ -722,7 +786,18 @@ static int loadBMP32(fp, pic24, w, h, colormask) /* 32-bit BI_BITFIELDS only */
 	    colorbits[1], colormask[1], bitshift[1], bitshift2[1],
 	    colorbits[2], colormask[2], bitshift[2], bitshift2[2]);
 
-  for (y = h-1; y >= 0; y--) {
+  if (rightsideup) {
+    ybegin = 0;
+    yend = h;
+    yinc = 1;
+  }
+  else {
+    ybegin = h-1;
+    yend = -1;
+    yinc = -1;
+  }
+
+  for (y = ybegin; y != yend; y += yinc) {
     pp = pic24 + (3 * w * y);
     if ((y&0x3f)==0) WaitCursor();
 
@@ -740,8 +815,7 @@ static int loadBMP32(fp, pic24, w, h, colormask) /* 32-bit BI_BITFIELDS only */
 
 
 /*******************************************/
-static u_int getshort(fp)
-     FILE *fp;
+static u_int getshort(FILE *fp)
 {
   int c, c1;
   c = getc(fp);  c1 = getc(fp);
@@ -750,8 +824,7 @@ static u_int getshort(fp)
 
 
 /*******************************************/
-static u_int getint(fp)
-     FILE *fp;
+static u_int getint(FILE *fp)
 {
   int c, c1, c2, c3;
   c = getc(fp);  c1 = getc(fp);  c2 = getc(fp);  c3 = getc(fp);
@@ -763,9 +836,7 @@ static u_int getint(fp)
 
 
 /*******************************************/
-static void putshort(fp, i)
-     FILE *fp;
-     int i;
+static void putshort(FILE *fp, int i)
 {
   int c, c1;
 
@@ -775,9 +846,7 @@ static void putshort(fp, i)
 
 
 /*******************************************/
-static void putint(fp, i)
-     FILE *fp;
-     int i;
+static void putint(FILE *fp, int i)
 {
   int c, c1, c2, c3;
   c  =  ((u_int) i)      & 0xff;
@@ -795,12 +864,7 @@ static byte pc2nc[256],r1[256],g1[256],b1[256];
 
 
 /*******************************************/
-int WriteBMP(fp,pic824,ptype,w,h,rmap,gmap,bmap,numcols,colorstyle)
-     FILE *fp;
-     byte *pic824;
-     int   ptype,w,h;
-     byte *rmap, *gmap, *bmap;
-     int   numcols, colorstyle;
+int WriteBMP(FILE *fp, byte *pic824, int ptype, int w, int h, byte *rmap, byte *gmap, byte *bmap, int numcols, int colorstyle)
 {
   /*
    * if PIC8, and colorstyle == F_FULLCOLOR, F_GREYSCALE, or F_REDUCED,
@@ -954,10 +1018,7 @@ int WriteBMP(fp,pic824,ptype,w,h,rmap,gmap,bmap,numcols,colorstyle)
 
 
 /*******************************************/
-static void writeBMP1(fp, pic8, w, h)
-     FILE *fp;
-     byte *pic8;
-     int  w,h;
+static void writeBMP1(FILE *fp, byte *pic8, int w, int h)
 {
   int   i,j,c,bitnum,padw;
   byte *pp;
@@ -986,10 +1047,7 @@ static void writeBMP1(fp, pic8, w, h)
 
 
 /*******************************************/
-static void writeBMP4(fp, pic8, w, h)
-     FILE *fp;
-     byte *pic8;
-     int  w,h;
+static void writeBMP4(FILE *fp, byte *pic8, int w, int h)
 {
   int   i,j,c,nybnum,padw;
   byte *pp;
@@ -1020,10 +1078,7 @@ static void writeBMP4(fp, pic8, w, h)
 
 
 /*******************************************/
-static void writeBMP8(fp, pic8, w, h)
-     FILE *fp;
-     byte *pic8;
-     int  w,h;
+static void writeBMP8(FILE *fp, byte *pic8, int w, int h)
 {
   int   i,j,padw;
   byte *pp;
@@ -1041,10 +1096,7 @@ static void writeBMP8(fp, pic8, w, h)
 
 
 /*******************************************/
-static void writeBMP24(fp, pic24, w, h)
-     FILE *fp;
-     byte *pic24;
-     int  w,h;
+static void writeBMP24(FILE *fp, byte *pic24, int w, int h)
 {
   int   i,j,padb;
   byte *pp;
@@ -1072,8 +1124,7 @@ static void writeBMP24(fp, pic24, w, h)
 
 
 /*******************************************/
-static int bmpError(fname, st)
-     const char *fname, *st;
+static int bmpError(const char *fname, const char *st)
 {
   SetISTR(ISTR_WARNING,"%s:  %s", fname, st);
   return 0;
