@@ -101,7 +101,6 @@
  * This software is provided "as is" without any express or implied warranty.
  */
 
-#define  NEEDSDIR       /* for S_IRUSR|S_IWUSR */
 #include "xv.h"
 
 #ifdef HAVE_PDS
@@ -170,9 +169,7 @@ static int LoadPDSPalette     PARM((char *, PICINFO *));
 /* The method of termination is unpredictable.  A pox on VMS.   */
 /* Sometimes we even get mixtures of CR's and LF's.  Sigh.      */
 
-static int getpdsrec(f,buff)
-     FILE *f;
-     char *buff;
+static int getpdsrec(FILE *f, char *buff)
 {
   static char *bp;
   static int count;
@@ -248,9 +245,7 @@ static int getpdsrec(f,buff)
  */
 
 /*******************************************/
-int LoadPDS(fname, pinfo)
-     char    *fname;
-     PICINFO *pinfo;
+int LoadPDS(char *fname, PICINFO *pinfo)
 {
   /* returns '1' on success, '0' on failure */
 
@@ -265,7 +260,7 @@ int LoadPDS(fname, pinfo)
   char	*tmp;
   const char   *ftypstr;
   unsigned long filesize;
-  char  sampletype[64];
+  char  sampletype[64+1];
 
   pinfo->type = PIC8;
   isfixed = TRUE;
@@ -655,21 +650,28 @@ int LoadPDS(fname, pinfo)
   *infobuff='\0';
   if (*spacecraft) {
     strncat(infobuff, spacecraft, sizeof(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
   }
 
   if (*target) {
     strncat(infobuff, ", ", sizeof(infobuff) - strlen(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
     strncat(infobuff, target, sizeof(infobuff) - strlen(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
   }
 
   if (*filtname) {
     strncat(infobuff, ", ", sizeof(infobuff) - strlen(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
     strncat(infobuff, filtname, sizeof(infobuff) - strlen(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
   }
 
   if (*itime) {
     strncat(infobuff, ", ", sizeof(infobuff) - strlen(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
     strncat(infobuff, itime, sizeof(infobuff) - strlen(infobuff) - 1);
+    infobuff[ sizeof(infobuff) - 1 ] = '\0';
   }
 
   SetISTR(ISTR_WARNING, "%s", infobuff);
@@ -890,15 +892,13 @@ int LoadPDS(fname, pinfo)
  */
 
 /*******************************************/
-static int Convert16BitImage(fname, pinfo, swab)
-     char *fname;
-     PICINFO *pinfo;
-     int swab;
+static int Convert16BitImage(char *fname, PICINFO *pinfo, int swab)
 {
   unsigned short *pShort;
   long i, j, k, l, n, *hist, nTot;
   size_t m;
   byte *lut, *pPix8;
+  byte *oldpic;
   FILE *fp;
   char  name[1024], *c;
 
@@ -999,10 +999,12 @@ static int Convert16BitImage(fname, pinfo, swab)
 
   /* convert the 16-bit image to 8-bit */
   lut[0] = 0;
-  free(pShort = (unsigned short *)pinfo->pic);
+  oldpic = pinfo->pic;
+  pShort = (unsigned short *)oldpic;
   pinfo->pic = pPix8;
   while(--n >= 0)
     *pPix8++ = lut[*pShort++];
+  free(oldpic);
   free(lut);
   return 1;
 }
@@ -1012,9 +1014,7 @@ static int Convert16BitImage(fname, pinfo, swab)
  */
 
 /*******************************************/
-static int LoadPDSPalette(fname, pinfo)
-     char    *fname;
-     PICINFO *pinfo;
+static int LoadPDSPalette(char *fname, PICINFO *pinfo)
 {
   FILE    *fp;
   char    name[1024], buf[256], *c;
