@@ -35,8 +35,8 @@
 #include "png.h"
 
 /*** Stuff for PNG Dialog box ***/
-#define PWIDE 318
-#define PHIGH 215
+#define PWIDE (318*dpiMult)
+#define PHIGH (215*dpiMult)
 
 #define DISPLAY_GAMMA 2.20  /* default display gamma */
 #define COMPRESSION   6     /* default zlib compression level, not max
@@ -46,17 +46,17 @@
 #define HAVE_tRNS  (info_ptr->valid & PNG_INFO_tRNS) */
 #define HAVE_tRNS  png_get_valid(png_ptr,info_ptr,PNG_INFO_tRNS)
 
-#define DWIDE    86
-#define DHIGH    104
-#define PFX      (PWIDE-93)
-#define PFY      44
-#define PFH      20
+#define DWIDE    (86*dpiMult)
+#define DHIGH    (104*dpiMult)
+#define PFX      (PWIDE - 93*dpiMult)
+#define PFY      (44*dpiMult)
+#define PFH      (20*dpiMult)
 
 #define P_BOK    0
 #define P_BCANC  1
 #define P_NBUTTS 2
 
-#define BUTTH    24
+#define BUTTH    (24*dpiMult)
 
 #define LF       10   /* a.k.a. '\n' on ASCII machines */
 #define CR       13   /* a.k.a. '\r' on ASCII machines */
@@ -121,29 +121,29 @@ png_default_write_data(png_structp png_ptr, png_bytep data, png_size_t length)
 
 
 /*******************************************/
-void CreatePNGW()
+void CreatePNGW(void)
 {
   pngW = CreateWindow("xv png", "XVPNG", NULL,
-                      PWIDE, PHIGH, infofg, infobg, 0);
+                      PWIDE, PHIGH, infofg, infobg, FALSE);
   if (!pngW) FatalError("can't create PNG window!");
 
   XSelectInput(theDisp, pngW, ExposureMask | ButtonPressMask | KeyPressMask);
 
-  DCreate(&cDial, pngW,  12, 25, DWIDE, DHIGH, (double)Z_NO_COMPRESSION,
+  DCreate(&cDial, pngW,  12*dpiMult, 25*dpiMult, DWIDE, DHIGH, (double)Z_NO_COMPRESSION,
           (double)Z_BEST_COMPRESSION, COMPRESSION, 1.0, 3.0,
           infofg, infobg, hicol, locol, "Compression", NULL);
 
-  DCreate(&gDial, pngW, DWIDE+27, 25, DWIDE, DHIGH, 1.0, 3.5,DISPLAY_GAMMA,0.01,0.2,
+  DCreate(&gDial, pngW, DWIDE + 27*dpiMult, 25*dpiMult, DWIDE, DHIGH, 1.0, 3.5,DISPLAY_GAMMA,0.01,0.2,
           infofg, infobg, hicol, locol, "Disp. Gamma", NULL);
 
-  CBCreate(&interCB, pngW,  DWIDE+30, DHIGH+3*LINEHIGH+2, "interlace",
+  CBCreate(&interCB, pngW,  DWIDE + 30*dpiMult, DHIGH + 3*LINEHIGH + 2*dpiMult, "interlace",
            infofg, infobg, hicol, locol);
 
   CBCreate(&FdefCB,   pngW, PFX, PFY, "Default",
            infofg, infobg, hicol, locol);
   FdefCB.val = 1;
 
-  CBCreate(&FnoneCB,  pngW, PFX, FdefCB.y + PFH + 4, "none",
+  CBCreate(&FnoneCB,  pngW, PFX, FdefCB.y + PFH + 4*dpiMult, "none",
            infofg, infobg, hicol, locol);
   CBCreate(&FsubCB,   pngW, PFX, FnoneCB.y + PFH, "sub",
            infofg, infobg, hicol, locol);
@@ -161,9 +161,9 @@ void CreatePNGW()
   CBSetActive(&FavgCB, !FdefCB.val);
   CBSetActive(&FPaethCB, !FdefCB.val);
 
-  BTCreate(&pbut[P_BOK], pngW, PWIDE-180-1, PHIGH-10-BUTTH-1, 80, BUTTH,
+  BTCreate(&pbut[P_BOK], pngW, PWIDE - 180*dpiMult - 1*dpiMult, PHIGH - 10*dpiMult - BUTTH - 1*dpiMult, 80*dpiMult, BUTTH,
           "Ok", infofg, infobg, hicol, locol);
-  BTCreate(&pbut[P_BCANC], pngW, PWIDE-90-1, PHIGH-10-BUTTH-1, 80, BUTTH,
+  BTCreate(&pbut[P_BCANC], pngW, PWIDE - 90*dpiMult - 1*dpiMult, PHIGH - 10*dpiMult - BUTTH - 1*dpiMult, 80*dpiMult, BUTTH,
           "Cancel", infofg, infobg, hicol, locol);
 
   XMapSubwindows(theDisp, pngW);
@@ -171,8 +171,7 @@ void CreatePNGW()
 
 
 /*******************************************/
-void PNGDialog(vis)
-     int vis;
+void PNGDialog(int vis)
 {
   if (vis) {
     CenterMapWindow(pngW, pbut[P_BOK].x + (int) pbut[P_BOK].w/2,
@@ -185,8 +184,7 @@ void PNGDialog(vis)
 
 
 /*******************************************/
-int PNGCheckEvent(xev)
-     XEvent *xev;
+int PNGCheckEvent(XEvent *xev)
 {
   /* check event to see if it's for one of our subwindows.  If it is,
      deal accordingly, and return '1'.  Otherwise, return '0' */
@@ -258,9 +256,7 @@ int PNGCheckEvent(xev)
 
 
 /*******************************************/
-void PNGSaveParams(fname, col)
-     char *fname;
-     int col;
+void PNGSaveParams(char *fname, int col)
 {
   filename = fname;
   colorType = col;
@@ -268,8 +264,7 @@ void PNGSaveParams(fname, col)
 
 
 /*******************************************/
-static void drawPD(x, y, w, h)
-     int x, y, w, h;
+static void drawPD(int x, int y, int w, int h)
 {
   const char *title   = "Save PNG file...";
 
@@ -293,23 +288,23 @@ static void drawPD(x, y, w, h)
 
   for (i=0; i<P_NBUTTS; i++) BTRedraw(&pbut[i]);
 
-  DrawString(pngW,       15,  6+ASCENT,                          title);
+  DrawString(pngW,       15*dpiMult,  6*dpiMult + ASCENT,                              title);
 
   sprintf(ctitle1, "Default = %d", COMPRESSION);
-  DrawString(pngW,       18,  6+DHIGH+cDial.y+ASCENT,            ctitle1);
-  DrawString(pngW,       17,  6+DHIGH+cDial.y+ASCENT+LINEHIGH,   ctitle2);
-  DrawString(pngW,       17,  6+DHIGH+cDial.y+ASCENT+2*LINEHIGH, ctitle3);
-  DrawString(pngW,       17,  6+DHIGH+cDial.y+ASCENT+3*LINEHIGH, ctitle4);
+  DrawString(pngW,       18*dpiMult,  6*dpiMult + DHIGH + cDial.y+ASCENT,              ctitle1);
+  DrawString(pngW,       17*dpiMult,  6*dpiMult + DHIGH + cDial.y+ASCENT + LINEHIGH,   ctitle2);
+  DrawString(pngW,       17*dpiMult,  6*dpiMult + DHIGH + cDial.y+ASCENT + 2*LINEHIGH, ctitle3);
+  DrawString(pngW,       17*dpiMult,  6*dpiMult + DHIGH + cDial.y+ASCENT + 3*LINEHIGH, ctitle4);
 
   sprintf(gtitle, "Default = %g", DISPLAY_GAMMA);
-  DrawString(pngW, DWIDE+30,  6+DHIGH+gDial.y+ASCENT,            gtitle);
+  DrawString(pngW, DWIDE + 30*dpiMult,  6*dpiMult + DHIGH + gDial.y+ASCENT,            gtitle);
 
-  ULineString(pngW, FdefCB.x, FdefCB.y-3-DESCENT, ftitle);
-  XDrawRectangle(theDisp, pngW, theGC, FdefCB.x-11, FdefCB.y-LINEHIGH-3,
-                                       93, 8*LINEHIGH+15);
+  ULineString(pngW, FdefCB.x, FdefCB.y - 3*dpiMult - DESCENT, ftitle);
+  XDrawRectangle(theDisp, pngW, theGC, FdefCB.x - 11*dpiMult, FdefCB.y - LINEHIGH - 3*dpiMult,
+                                       93*dpiMult, 8*LINEHIGH + 15*dpiMult);
   CBRedraw(&FdefCB);
-  XDrawLine(theDisp, pngW, theGC, FdefCB.x-11, FdefCB.y+LINEHIGH+4,
-                                  FdefCB.x+82, FdefCB.y+LINEHIGH+4);
+  XDrawLine(theDisp, pngW, theGC, FdefCB.x - 11*dpiMult, FdefCB.y + LINEHIGH + 4*dpiMult,
+                                  FdefCB.x + 82*dpiMult, FdefCB.y + LINEHIGH + 4*dpiMult);
 
   CBRedraw(&FnoneCB);
   CBRedraw(&FupCB);
@@ -324,8 +319,7 @@ static void drawPD(x, y, w, h)
 
 
 /*******************************************/
-static void clickPD(x,y)
-     int x,y;
+static void clickPD(int x, int y)
 {
   int i;
   BUTT *bp;
@@ -373,8 +367,7 @@ static void clickPD(x,y)
 
 
 /*******************************************/
-static void doCmd(cmd)
-     int cmd;
+static void doCmd(int cmd)
 {
   switch (cmd) {
     case P_BOK:
@@ -403,7 +396,7 @@ static void doCmd(cmd)
 
 
 /*******************************************/
-static void writePNG()
+static void writePNG(void)
 {
   FILE       *fp;
   int         w, h, nc, rv, ptype, pfree;
@@ -428,12 +421,7 @@ static void writePNG()
 
 
 /*******************************************/
-int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
-     FILE *fp;
-     byte *pic;
-     int   ptype, w, h;
-     byte *rmap, *gmap, *bmap;
-     int   numcols;
+int WritePNG(FILE *fp, byte *pic, int ptype, int w, int h, byte *rmap, byte *gmap, byte *bmap, int numcols)
      /* FIXME?  what's diff between picComments and WriteGIF's comment arg? */
 {
   png_struct *png_ptr;
@@ -443,12 +431,12 @@ int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
   byte        r1[256], g1[256], b1[256];  /* storage for deduped palette */
   byte        pc2nc[256];  /* for duplicated-color remapping (1st level) */
   byte        remap[256];  /* for bw/grayscale remapping (2nd level) */
-  int         i, j, numuniqcols=0, filter, linesize, pass;
+  int         i, j, numuniqcols, filter, linesize, pass;
   byte       *p, *png_line;
   char        software[256];
   char       *savecmnt;
   /* for storing values until all are accumulated, so that the image header can be set in full */
-  int         _bit_depth,_color_type,_interlace_type,_compression_type,_filter_type;
+  int         _bit_depth,_color_type,_interlace_type;
   png_uint_32 _width,_height;
   png_time    _mod_time;
 
@@ -508,7 +496,7 @@ int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
   _interlace_type = interCB.val ? PNG_INTERLACE_ADAM7 : PNG_INTERLACE_NONE;
 
   linesize = 0;   /* quiet a compiler warning */
-
+  numuniqcols = 0;
 
   /* GRR 20070331:  remap palette to eliminate duplicated colors (as in
    *   xvgifwr.c) */
@@ -706,9 +694,9 @@ int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
 
   Display_Gamma = gDial.val;  /* Save the current gamma for loading */
 
-// GRR FIXME:  add .Xdefaults option to omit writing gamma (size, cumulative errors when editing)--alternatively, modify save box to include "omit" checkbox
+/* GRR FIXME:  add .Xdefaults option to omit writing gamma (size, cumulative errors when editing)--alternatively, modify save box to include "omit" checkbox */
   png_set_gAMA(png_ptr,info_ptr,1.0/gDial.val);
-/* doesn't seem to be a way to set valid directly anymore, unnecessary maybe.. 
+/* doesn't seem to be a way to set valid directly anymore, unnecessary maybe..
   info_ptr->valid |= PNG_INFO_gAMA; */
 
 /* might need to be png_write_info_before_PLTE() ... */
@@ -762,7 +750,7 @@ int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
       key = savecmnt;
       png_get_text(png_ptr,info_ptr,&tp,&mt); /* to get 'max_text' */
       tp = text;
-      nt = 0;      
+      nt = 0;
 
       comment = strchr(key, ':');
 
@@ -874,7 +862,7 @@ int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
 
   if (text) {
     free(text);
-    /* must do this or png_destroy_write_struct() 0.97+ will free text again: 
+    /* must do this or png_destroy_write_struct() 0.97+ will free text again:
     info_ptr->text = (png_textp)NULL; */
     if (savecmnt)
     {
@@ -890,9 +878,7 @@ int WritePNG(fp, pic, ptype, w, h, rmap, gmap, bmap, numcols)
 
 
 /*******************************************/
-int LoadPNG(fname, pinfo)
-     char    *fname;
-     PICINFO *pinfo;
+int LoadPNG(char *fname, PICINFO *pinfo)
 /*******************************************/
 {
   /* returns '1' on success */
@@ -908,9 +894,8 @@ int LoadPNG(fname, pinfo)
   int gray_to_rgb;
   size_t commentsize;
   /* temp storage vars for libpng15 migration */
-  int         _bit_depth,_color_type,_interlace_type,_compression_type,_filter_type,_num_text,_num_palette;
+  int         _bit_depth,_color_type,_interlace_type,_num_text,_num_palette;
   png_uint_32 _width,_height;
-  png_timep   _mod_time;
   double      _gamma;
   png_textp   _text;
   png_colorp  _palette;
@@ -1016,7 +1001,7 @@ int LoadPNG(fname, pinfo)
 	  ", %sinterlaced. (%d bytes)",
 	  _interlace_type ? "" : "non-", filesize);
 
-  sprintf(pinfo->shrtInfo, "%lux%lu PNG", _width, _height);
+  sprintf(pinfo->shrtInfo, "%lux%lu PNG", (long unsigned int) _width, (long unsigned int) _height);
 
   if (_bit_depth < 8)
       png_set_packing(png_ptr);
@@ -1175,9 +1160,7 @@ int LoadPNG(fname, pinfo)
 
 /*******************************************/
 static void
-png_xv_error(png_ptr, message)
-     png_structp png_ptr;
-     png_const_charp message;
+png_xv_error(png_structp png_ptr, png_const_charp message)
 {
   SetISTR(ISTR_WARNING,"%s:  libpng error: %s", fbasename, message);
 
@@ -1187,9 +1170,7 @@ png_xv_error(png_ptr, message)
 
 /*******************************************/
 static void
-png_xv_warning(png_ptr, message)
-     png_structp png_ptr;
-     png_const_charp message;
+png_xv_warning(png_structp png_ptr, png_const_charp message)
 {
   if (!png_ptr)
     return;
@@ -1200,7 +1181,7 @@ png_xv_warning(png_ptr, message)
 
 /*******************************************/
 void
-VersionInfoPNG()	/* GRR 19980605 */
+VersionInfoPNG(void)	/* GRR 19980605 */
 {
   fprintf(stderr, "   Compiled with libpng %s; using libpng %s.\n",
     PNG_LIBPNG_VER_STRING, png_libpng_ver);
